[sawfish] description for view-clipboard



commit e1c366f756307089f47033c9a6a2ca255c6e2aa4
Author: chrisb <zanghar freenet de>
Date:   Sat Sep 12 16:30:13 2009 +0200

    description for view-clipboard

 ChangeLog                        |    2 ++
 lisp/sawfish/wm/commands/user.jl |    6 ++++--
 2 files changed, 6 insertions(+), 2 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 0fec7dc..1c9882f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -46,6 +46,8 @@
 	* Makefile.in: don't remove ancient Sawmill.desktop
 
 	* lisp/sawfish/wm/user.jl: display-message-with-timeout now must be called with a timeout
+	                           header updated
+				   description for view-clipboard
 
 2009-09-11  Christopher Bratusek <zanghar freenet de>
 	* configure.in
diff --git a/lisp/sawfish/wm/commands/user.jl b/lisp/sawfish/wm/commands/user.jl
index 77510a3..681106e 100644
--- a/lisp/sawfish/wm/commands/user.jl
+++ b/lisp/sawfish/wm/commands/user.jl
@@ -1,6 +1,6 @@
 #| xterm.jl -- command to launch an xterm
 
-   $Id: xterm.jl,v 1.7 2002/04/21 22:25:12 jsh Exp $
+   $Id: user.jl,v 1.7 2002/04/21 22:25:12 jsh Exp $
 
    Copyright (C) 2000 John Harper <john dcs warwick ac uk>
 
@@ -92,6 +92,8 @@
       (file-exists-p (concat dir "/" cmd)))
       (string-split ":" (getenv "PATH"))))
 
+  ;; view-clipboard
+  ;; view the content of the primary x-clipboard
   (define (view-clipboard)
     "Show the contents of the clipboard in a message window"
     (let ((c (x-get-selection 'PRIMARY)))
@@ -1,6 +1,6 @@
-#| xterm.jl -- command to launch an xterm
+#| user.jl -- command to launch an xterm/brower and more
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]